Office Jobs, Admin Vacancies & Secretarial Careers | Office Angels UK
Description: Office Angels recruitment consultants, sourcing secretarial, administration and office staff since 1986. Search for the latest UK and Ireland jobs.

[City],[Region],[Country],[Province],[PostalCode]
[City],[Province]

- [enter text]

- Find a job
- Help & advice
- Working with you

worldLnk,bckTop,shrBtn_Bottom,brdCrmb,shrBtn

# Find your ideal job... Search by keyword Your location Advanced search Category Permanent/Temporary Posted within [days] Collapse

## Browse jobs by specialism
Accountancy & finance Jobs Admin, secretarial & PA Jobs Banking & Finance Jobs Property, Building & Construction Jobs | Call Centre & Service Jobs Charity Jobs Education & Childcare Jobs Engineering Jobs | Hospitality & Travel Jobs Human Resource Jobs IT Jobs Legal Jobs | Manufacturing Jobs Marketing Jobs Sales & Retail Jobs Telecommunications Jobs

## Join us on:

## Hiring in a booming economy Hiring isn’t what it used to be, and candidates are in alarmingly short supply. Here’s how to secure the talent you want. Read more >

## Salary survey Every six months we analyse salary trends to bring you a free report with an accurate snapshot of the UK jobs market. Read more >

## Futures newsletter Sent every month, Futures is our free email newsletter packed with tips and advice Sign up >

## Latest Tweet Tweets by @OfficeAngelsUK ## Receive job alerts

### Find a job Job search Find a branch | ### Jobseekers Advice for jobseekers Skills & training News & opinion | ### Employers Working with you Advice for employers Who we work with | ### News & opinion News Blogs Employment law | ### About us The Adecco Group Our diversity partners Careers

- © Office Angels 2013
- Contact us
- Feedback
- Terms & Conditions
- Privacy Policy
- Cookie Policy
- Press office
- Careers at Office Angels

x

## Receive jobs by email matching:

close
close
close
close
close
close
close